@@ -1,23 +1,10 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
-    Copyright (c) 2003 Carsten Pfeiffer <pfeiffer@kde.org>
-    Copyright (c) 2005 Ingo Kloecker <kloecker@kde.org>
+    SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
+    SPDX-FileCopyrightText: 2003 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2005 Ingo Kloecker <kloecker@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <QDate>
@@ -26,11 +13,11 @@
 #include <QUuid>
 
 #include "kcontacts_debug.h"
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
+#include "addressee.h"
 #include "addresseehelper.h"
 #include "field.h"
-#include "addressee.h"
 
 using namespace KContacts;
 
@@ -49,7 +36,7 @@ public:
         , mChanged(false)
         , mBirthdayWithTime(false)
     {
-        //We avoid the curly braces so the string is RFC4122 compliant and can be used as urn
+        // We avoid the curly braces so the string is RFC4122 compliant and can be used as urn
     }
 
     Private(const Private &other)
@@ -152,8 +139,8 @@ public:
     Org::List mOrgExtraList;
     NickName::List mNickNameExtraList;
     ClientPidMap::List mClientPidMapList;
-    bool mEmpty    : 1;
-    bool mChanged  : 1;
+    bool mEmpty : 1;
+    bool mChanged : 1;
     bool mBirthdayWithTime;
 };
 
@@ -187,54 +174,55 @@ bool Addressee::operator==(const Addressee &addressee) const
         return false;
     }
 
-    if (d->mName != addressee.d->mName
+    if (d->mName != addressee.d->mName //
         && !(d->mName.isEmpty() && addressee.d->mName.isEmpty())) {
         qCDebug(KCONTACTS_LOG) << "name differs";
         return false;
     }
 
-    if (d->mFormattedName != addressee.d->mFormattedName
+    if (d->mFormattedName != addressee.d->mFormattedName //
         && !(d->mFormattedName.isEmpty() && addressee.d->mFormattedName.isEmpty())) {
         qCDebug(KCONTACTS_LOG) << "formattedName differs";
         return false;
     }
 
-    if (d->mFamilyName != addressee.d->mFamilyName
+    if (d->mFamilyName != addressee.d->mFamilyName //
         && !(d->mFamilyName.isEmpty() && addressee.d->mFamilyName.isEmpty())) {
         qCDebug(KCONTACTS_LOG) << "familyName differs";
         return false;
     }
 
-    if (d->mGivenName != addressee.d->mGivenName
+    if (d->mGivenName != addressee.d->mGivenName //
         && !(d->mGivenName.isEmpty() && addressee.d->mGivenName.isEmpty())) {
         qCDebug(KCONTACTS_LOG) << "givenName differs";
         return false;
     }
 
-    if (d->mAdditionalName != addressee.d->mAdditionalName
+    if (d->mAdditionalName != addressee.d->mAdditionalName //
         && !(d->mAdditionalName.isEmpty() && addressee.d->mAdditionalName.isEmpty())) {
         qCDebug(KCONTACTS_LOG) << "additionalName differs";
         return false;
     }
 
-    if (d->mPrefix != addressee.d->mPrefix
+    if (d->mPrefix != addressee.d->mPrefix //
         && !(d->mPrefix.isEmpty() && addressee.d->mPrefix.isEmpty())) {
         qCDebug(KCONTACTS_LOG) << "prefix differs";
         return false;
     }
 
-    if (d->mSuffix != addressee.d->mSuffix
+    if (d->mSuffix != addressee.d->mSuffix //
         && !(d->mSuffix.isEmpty() && addressee.d->mSuffix.isEmpty())) {
         qCDebug(KCONTACTS_LOG) << "suffix differs";
         return false;
     }
 
-    if (d->mBirthday != addressee.d->mBirthday || d->mBirthdayWithTime != addressee.d->mBirthdayWithTime) {
+    if (d->mBirthday != addressee.d->mBirthday //
+        || d->mBirthdayWithTime != addressee.d->mBirthdayWithTime) {
         qCDebug(KCONTACTS_LOG) << "birthday differs";
         return false;
     }
 
-    if (d->mMailer != addressee.d->mMailer
+    if (d->mMailer != addressee.d->mMailer //
         && !(d->mMailer.isEmpty() && addressee.d->mMailer.isEmpty())) {
         qCDebug(KCONTACTS_LOG) << "mailer differs";
         return false;
@@ -250,25 +238,25 @@ bool Addressee::operator==(const Addressee &addressee) const
         return false;
     }
 
-    if (d->mDepartment != addressee.d->mDepartment
+    if (d->mDepartment != addressee.d->mDepartment //
         && !(d->mDepartment.isEmpty() && addressee.d->mDepartment.isEmpty())) {
         qCDebug(KCONTACTS_LOG) << "department differs";
         return false;
     }
 
-    if (d->mNote != addressee.d->mNote
+    if (d->mNote != addressee.d->mNote //
         && !(d->mNote.isEmpty() && addressee.d->mNote.isEmpty())) {
         qCDebug(KCONTACTS_LOG) << "note differs";
         return false;
     }
 
-    if (d->mProductId != addressee.d->mProductId
+    if (d->mProductId != addressee.d->mProductId //
         && !(d->mProductId.isEmpty() && addressee.d->mProductId.isEmpty())) {
         qCDebug(KCONTACTS_LOG) << "productId differs";
         return false;
     }
 
-    if (d->mSortString != addressee.d->mSortString
+    if (d->mSortString != addressee.d->mSortString //
         && !(d->mSortString.isEmpty() && addressee.d->mSortString.isEmpty())) {
         qCDebug(KCONTACTS_LOG) << "sortString differs";
         return false;
@@ -570,7 +558,7 @@ void Addressee::insertFieldGroup(const FieldGroup &fieldGroup)
 {
     if (fieldGroup.isValid()) {
         d->mEmpty = false;
-        //TODO don't duplicate ?
+        // TODO don't duplicate ?
         d->mFieldGroupList.append(fieldGroup);
     }
 }
@@ -590,7 +578,7 @@ void Addressee::insertClientPidMap(const ClientPidMap &clientpidmap)
 {
     if (clientpidmap.isValid()) {
         d->mEmpty = false;
-        //TODO don't duplicate ?
+        // TODO don't duplicate ?
         d->mClientPidMapList.append(clientpidmap);
     }
 }
@@ -599,7 +587,7 @@ void Addressee::insertImpp(const Impp &impp)
 {
     if (impp.isValid()) {
         d->mEmpty = false;
-        //Don't duplicate ?
+        // Don't duplicate ?
         d->mImpps.append(impp);
     }
 }
@@ -618,7 +606,7 @@ Impp::List Addressee::imppList() const
 void Addressee::insertCalendarUrl(const CalendarUrl &calendarUrl)
 {
     d->mEmpty = false;
-    //TODO verify that there is not same calendarurl
+    // TODO verify that there is not same calendarurl
     if (calendarUrl.isValid()) {
         d->mCalendarUrl.append(calendarUrl);
     }
@@ -1377,10 +1365,8 @@ QString Addressee::soundLabel()
 void Addressee::setNameFromString(const QString &s)
 {
     QString str = s;
-    //remove enclosing quotes from string
-    if (str.length() > 1
-        && s[0] == QLatin1Char('"')
-        && s[s.length() - 1] == QLatin1Char('"')) {
+    // remove enclosing quotes from string
+    if (str.length() > 1 && s[0] == QLatin1Char('"') && s[s.length() - 1] == QLatin1Char('"')) {
         str = s.mid(1, s.length() - 2);
     }
 
@@ -1555,11 +1541,13 @@ QString Addressee::realName() const
 
 QString Addressee::assembledName() const
 {
+    // clang-format off
     const QString name = prefix() + QLatin1Char(' ')
-                         +givenName() + QLatin1Char(' ')
-                         +additionalName() + QLatin1Char(' ')
-                         +familyName() + QLatin1Char(' ')
-                         +suffix();
+                         + givenName() + QLatin1Char(' ')
+                         + additionalName() + QLatin1Char(' ')
+                         + familyName() + QLatin1Char(' ')
+                         + suffix();
+    // clang-format on
 
     return name.simplified();
 }
@@ -2322,7 +2310,7 @@ void Addressee::parseEmailAddress(const QString &rawEmail, QString &fullName, QS
     fullName.clear();
     email.clear();
     if (rawEmail.isEmpty()) {
-        return;    // KPIM::AddressEmpty;
+        return; // KPIM::AddressEmpty;
     }
 
     // The code works on 8-bit strings, so convert the input to UTF-8.
@@ -2339,7 +2327,7 @@ void Addressee::parseEmailAddress(const QString &rawEmail, QString &fullName, QS
     enum sourceLevel {
         TopLevel,
         InComment,
-        InAngleAddress
+        InAngleAddress,
     };
     sourceLevel context = TopLevel;
     bool inQuotedString = false;
@@ -2375,15 +2363,15 @@ void Addressee::parseEmailAddress(const QString &rawEmail, QString &fullName, QS
                 if (*p) {
                     displayName += *p;
                 } else {
-                    //return KPIM::UnexpectedEnd;
+                    // return KPIM::UnexpectedEnd;
                     goto ABORT_PARSING;
                 }
                 break;
             case ',':
                 if (!inQuotedString) {
-                    //if ( allowMultipleAddresses )
+                    // if ( allowMultipleAddresses )
                     //  stop = true;
-                    //else
+                    // else
                     //  return KPIM::UnexpectedComma;
                     goto ABORT_PARSING;
                 } else {
@@ -2415,7 +2403,7 @@ void Addressee::parseEmailAddress(const QString &rawEmail, QString &fullName, QS
                 if (*p) {
                     comment += *p;
                 } else {
-                    //return KPIM::UnexpectedEnd;
+                    // return KPIM::UnexpectedEnd;
                     goto ABORT_PARSING;
                 }
                 break;
@@ -2442,7 +2430,7 @@ void Addressee::parseEmailAddress(const QString &rawEmail, QString &fullName, QS
                 if (*p) {
                     addrSpec += *p;
                 } else {
-                    //return KPIM::UnexpectedEnd;
+                    // return KPIM::UnexpectedEnd;
                     goto ABORT_PARSING;
                 }
                 break;
@@ -2458,23 +2446,23 @@ ABORT_PARSING:
     comment = comment.trimmed();
     addrSpec = addrSpec.trimmed();
     fullName = QString::fromUtf8(displayName);
-    email = QString::fromUtf8(addrSpec);  // check for errors
+    email = QString::fromUtf8(addrSpec); // check for errors
     if (inQuotedString) {
-        return;    // KPIM::UnbalancedQuote;
+        return; // KPIM::UnbalancedQuote;
     }
     if (context == InComment) {
-        return;    // KPIM::UnbalancedParens;
+        return; // KPIM::UnbalancedParens;
     }
     if (context == InAngleAddress) {
-        return;    // KPIM::UnclosedAngleAddr;
+        return; // KPIM::UnclosedAngleAddr;
     }
 
     if (addrSpec.isEmpty()) {
         if (displayName.isEmpty()) {
-            return;    // KPIM::NoAddressSpec;
+            return; // KPIM::NoAddressSpec;
         } else {
-            //addrSpec = displayName;
-            //displayName.truncate( 0 );
+            // addrSpec = displayName;
+            // displayName.truncate( 0 );
             // Address of the form "foo@bar" or "foo@bar (Name)".
             email = fullName;
             fullName = QString::fromUtf8(comment);
@@ -2482,10 +2470,14 @@ ABORT_PARSING:
     }
 
     email = email.toLower();
-    // Check that we do not have any extra characters on the end of the
-    // strings
-    unsigned int len = fullName.length();
-    if (fullName[0] == QLatin1Char('"') && fullName[len - 1] == QLatin1Char('"')) {
+
+    // Check that the full name is not enclosed in balanced double quotes.
+    // If it is then remove them.
+    const unsigned int len = fullName.length();
+    if (len < 3) { // not long enough to be
+        return;
+    }
+    if (fullName.startsWith(QLatin1Char('"')) && fullName.endsWith(QLatin1Char('"'))) {
         fullName = fullName.mid(1, len - 2);
     }
 }
@@ -2661,7 +2653,7 @@ bool listEquals(const QStringList &list, const QStringList &pattern)
     return true;
 }
 
-template <typename T>
+template<typename T>
 static QVariantList toVariantList(const QVector<T> &v)
 {
     QVariantList l;
